@@ -8,19 +8,19 @@ function(coord){
   sphericalErros<-SphericalStandardError3D(coord)
   m_direction<-MeanDirection3D(coord);
   m_module<-MeanModule3D(coord);
-  vm_parameter<-VonMisesParameter3D(coord);
+  vm_parameter<-ConcentrationParameter3D(coord);
 		
 	
   print("*************************************************************");
   print("****                                                     ****");
-  print("****            SPHERICAL STATISTICS - ANGLE             ****");
+  print("****            SPHERICAL STATISTICS - ANGLES             ****");
   print("****                                                     ****");
   print("*************************************************************");
 	
   print(paste("SPHERICAL STANDARD ERROR = ",sphericalErros));
   print(paste("MEAN MODULE = ",m_module));
-  print(paste("VON MISES PARAMETER = ",vm_parameter));
-  print(paste("MEAN DIRECTION = ",m_direction));
+  print(paste("CONCENTRATION PARAMETER = ",vm_parameter));
+  print(paste("COLATITUDE = ",m_direction[1],", LATITUDE = ",m_direction[2]));
+  }
 
-}
 
