@@ -5,11 +5,23 @@ function(coord){
   z<-coord[,3];
   n_elements=length(x);
   R=sqrt((sum(x)*sum(x))+(sum(y)*sum(y))+(sum(z)*sum(z)));
+  
   meanX<-sum(x)/R;
   meanY<-sum(y)/R;
   meanZ<-sum(z)/R;
   
-  meanLongitud<-atan(meanY/meanX);
+  if((meanY>0)&(meanX>0)){
+    meanLongitud<-atan(meanY/meanX);
+  }
+  if((meanY>0)&(meanX<0)){
+    meanLongitud<-atan(meanY/meanX)+180;
+  }
+  if((meanY<0)&(meanX<0)){
+    meanLongitud<-atan(meanY/meanX)+180;
+  }
+  if((meanY<0)&(meanX>0)){
+    meanLongitud<-atan(meanY/meanX)+360;
+  }
   meanLongitud<-ToSexagesimal3D(meanLongitud);
   
   meanColatitud<-acos(meanZ);
